@@ -30,8 +30,13 @@ import numpy
 import pandas
 import random
 import soundfile
-import threading
-import pyroomacoustics
+
+has_pyroom = True
+try:
+   import pyroomacoustics
+except ImportError:
+   has_pyroom = False
+
 
 
 __author__ = "Anthony Larcher and Sylvain Meignier"
@@ -210,155 +215,156 @@ class AddNoiseFromSilence(object):
         return data.squeeze(), sample[1], sample[2], sample[3], sample[4], sample[5]
 
 
+if has_pyroom:
 class AddReverb(object):
-    """Simulate indoor reverberation
+     """Simulate indoor reverberation
 
-    Parameters
-    ----------
-    depth : (float, float), optional
-        Minimum and maximum values for room depth (in meters).
-        Defaults to (2.0, 10.0).
-    width : (float, float), optional
-        Minimum and maximum values for room width (in meters).
-        Defaults to (1.0, 10.0).
-    height : (float, float), optional
-        Minimum and maximum values for room heigth (in meters).
-        Defaults to (2.0, 5.0).
-    absorption : (float, float), optional
-        Minimum and maximum values of walls absorption coefficient.
-        Defaults to (0.2, 0.9).
-    noise : str or list of str, optional
-        `pyannote.database` collection(s) used for adding noise.
-        Defaults to "MUSAN.Collection.BackgroundNoise"
-    snr : (float, float), optional
-        Minimum and maximum values of signal-to-noise ratio.
-        Defaults to (5.0, 15.0)
+     Parameters
+     ----------
+     depth : (float, float), optional
+         Minimum and maximum values for room depth (in meters).
+         Defaults to (2.0, 10.0).
+     width : (float, float), optional
+         Minimum and maximum values for room width (in meters).
+         Defaults to (1.0, 10.0).
+     height : (float, float), optional
+         Minimum and maximum values for room heigth (in meters).
+         Defaults to (2.0, 5.0).
+     absorption : (float, float), optional
+         Minimum and maximum values of walls absorption coefficient.
+         Defaults to (0.2, 0.9).
+     noise : str or list of str, optional
+         `pyannote.database` collection(s) used for adding noise.
+         Defaults to "MUSAN.Collection.BackgroundNoise"
+     snr : (float, float), optional
+         Minimum and maximum values of signal-to-noise ratio.
+         Defaults to (5.0, 15.0)
 
-    """
+     """
 
-    def __init__(
-        self,
-        depth=(2.0, 10.0),
-        width=(1.0, 10.0),
-        height=(2.0, 5.0),
-        absorption=(0.2, 0.9),
-        noise=None,
-        snr=(5.0, 15.0)
-    ):
+     def __init__(
+         self,
+         depth=(2.0, 10.0),
+         width=(1.0, 10.0),
+         height=(2.0, 5.0),
+         absorption=(0.2, 0.9),
+         noise=None,
+         snr=(5.0, 15.0)
+     ):
 
-        super().__init__()
-        self.depth = depth
-        self.width = width
-        self.height = height
-        self.absorption = absorption
-        self.max_order_ = 17
+         super().__init__()
+         self.depth = depth
+         self.width = width
+         self.height = height
+         self.absorption = absorption
+         self.max_order_ = 17
 
-        self.noise = noise
-        self.snr = snr
-        self.noise_ = noise
+         self.noise = noise
+         self.snr = snr
+         self.noise_ = noise
 
-        self.n_rooms_ = 128
-        self.new_rooms_prob_ = 0.001
-        self.main_lock_ = threading.Lock()
-        self.rooms_ = collections.deque(maxlen=self.n_rooms_)
-        self.room_lock_ = [threading.Lock() for _ in range(self.n_rooms_)]
+         self.n_rooms_ = 128
+         self.new_rooms_prob_ = 0.001
+         self.main_lock_ = threading.Lock()
+         self.rooms_ = collections.deque(maxlen=self.n_rooms_)
+         self.room_lock_ = [threading.Lock() for _ in range(self.n_rooms_)]
 
-    @staticmethod
-    def random(m, M):
-        """
+     @staticmethod
+     def random(m, M):
+         """
 
-        :param m:
-        :param M:
-        :return:
-        """
-        return (M - m) * numpy.random.random_sample() + m
+         :param m:
+         :param M:
+         :return:
+         """
+         return (M - m) * numpy.random.random_sample() + m
 
-    def new_room(self, sample_rate: int):
-        """
+     def new_room(self, sample_rate: int):
+         """
 
-        :param sample_rate:
-        :return:
-        """
-        # generate a room at random
-        depth = self.random(*self.depth)
-        width = self.random(*self.width)
-        height = self.random(*self.height)
-        absorption = self.random(*self.absorption)
-        room = pyroomacoustics.ShoeBox(
-            [depth, width, height],
-            fs=sample_rate,
-            absorption=absorption,
-            max_order=self.max_order_,
-        )
+         :param sample_rate:
+         :return:
+         """
+         # generate a room at random
+         depth = self.random(*self.depth)
+         width = self.random(*self.width)
+         height = self.random(*self.height)
+         absorption = self.random(*self.absorption)
+         room = pyroomacoustics.ShoeBox(
+             [depth, width, height],
+             fs=sample_rate,
+             absorption=absorption,
+             max_order=self.max_order_,
+         )
 
-        # play the original audio chunk at a random location
-        original = [
-            self.random(0, depth),
-            self.random(0, width),
-            self.random(0, height),
-        ]
-        room.add_source(original)
+         # play the original audio chunk at a random location
+         original = [
+             self.random(0, depth),
+             self.random(0, width),
+             self.random(0, height),
+         ]
+         room.add_source(original)
 
-        # play the noise audio chunk at a random location
-        noise = [self.random(0, depth), self.random(0, width), self.random(0, height)]
-        room.add_source(noise)
+         # play the noise audio chunk at a random location
+         noise = [self.random(0, depth), self.random(0, width), self.random(0, height)]
+         room.add_source(noise)
 
-        # place the microphone at a random location
-        microphone = [
-            self.random(0, depth),
-            self.random(0, width),
-            self.random(0, height),
-        ]
-        room.add_microphone_array(
-            pyroomacoustics.MicrophoneArray(numpy.c_[microphone, microphone], sample_rate)
-        )
+         # place the microphone at a random location
+         microphone = [
+             self.random(0, depth),
+             self.random(0, width),
+             self.random(0, height),
+         ]
+         room.add_microphone_array(
+             pyroomacoustics.MicrophoneArray(numpy.c_[microphone, microphone], sample_rate)
+         )
 
-        room.compute_rir()
+         room.compute_rir()
 
-        return room
+         return room
 
-    def __call__(self, sample):
+     def __call__(self, sample):
 
-        data = sample[0]
-        if sample[5]:
+         data = sample[0]
+         if sample[5]:
 
-            with self.main_lock_:
+             with self.main_lock_:
 
-                # initialize rooms (with 2 sources and 1 microphone)
-                while len(self.rooms_) < self.n_rooms_:
-                    room = self.new_room(self.sample_rate)
-                    self.rooms_.append(room)
+                 # initialize rooms (with 2 sources and 1 microphone)
+                 while len(self.rooms_) < self.n_rooms_:
+                     room = self.new_room(self.sample_rate)
+                     self.rooms_.append(room)
 
-                # create new room with probability new_rooms_prob_
-                if numpy.random.rand() > 1.0 - self.new_rooms_prob_:
-                    room = self.new_room(self.sample_rate)
-                    self.rooms_.append(room)
+                 # create new room with probability new_rooms_prob_
+                 if numpy.random.rand() > 1.0 - self.new_rooms_prob_:
+                     room = self.new_room(self.sample_rate)
+                     self.rooms_.append(room)
 
-                # choose one room at random
-                index = numpy.random.choice(self.n_rooms_)
+                 # choose one room at random
+                 index = numpy.random.choice(self.n_rooms_)
 
-            # lock chosen room to ensure room.sources are not updated concurrently
-            with self.room_lock_[index]:
+             # lock chosen room to ensure room.sources are not updated concurrently
+             with self.room_lock_[index]:
 
-                room = self.rooms_[index]
+                 room = self.rooms_[index]
 
-                # play normalized original audio chunk at source #1
-                n_samples = len(data)
-                data = normalize(original).squeeze()
-                room.sources[0].add_signal(data)
+                 # play normalized original audio chunk at source #1
+                 n_samples = len(data)
+                 data = normalize(original).squeeze()
+                 room.sources[0].add_signal(data)
 
-                # generate noise with random SNR
-                noise = self.noise_(n_samples, self.sample_rate).squeeze()
-                snr = self.random(*self.snr)
-                alpha = numpy.exp(-numpy.log(10) * snr / 20)
-                noise *= alpha
+                 # generate noise with random SNR
+                 noise = self.noise_(n_samples, self.sample_rate).squeeze()
+                 snr = self.random(*self.snr)
+                 alpha = numpy.exp(-numpy.log(10) * snr / 20)
+                 noise *= alpha
 
-                # play noise at source #2
-                room.sources[1].add_signal(noise)
+                 # play noise at source #2
+                 room.sources[1].add_signal(noise)
 
-                # simulate room and return microphone signal
-                room.simulate()
-                data = room.mic_array.signals[0, :n_samples, numpy.newaxis]
+                 # simulate room and return microphone signal
+                 room.simulate()
+                 data = room.mic_array.signals[0, :n_samples, numpy.newaxis]
 
-        return data, sample[1], sample[2], sample[3] , sample[4], sample[5]
+         return data, sample[1], sample[2], sample[3] , sample[4], sample[5]
 
