@@ -23,7 +23,7 @@
 
 
 """
-Copyright 2014-2019 Anthony Larcher
+Copyright 2014-2021 Anthony Larcher
 
 :mod:`statserver` provides methods to manage zero and first statistics.
 """
@@ -36,6 +36,7 @@ import numpy
 import os
 import scipy
 import sys
+import tqdm
 import warnings
 
 from sidekit.bosaris import IdMap
@@ -53,7 +54,7 @@ if STAT_TYPE == numpy.float32:
 
 __license__ = "LGPL"
 __author__ = "Anthony Larcher"
-__copyright__ = "Copyright 2014-2019 Anthony Larcher"
+__copyright__ = "Copyright 2014-2021 Anthony Larcher"
 __maintainer__ = "Anthony Larcher"
 __email__ = "anthony.larcher@univ-lemans.fr"
 __status__ = "Production"
@@ -890,7 +891,7 @@ class StatServer:
         unique_speaker = numpy.unique(self.modelset)
         W = numpy.zeros((vect_size, vect_size))
 
-        for speakerID in unique_speaker:
+        for speakerID in tqdm.tqdm(unique_speaker):
             spk_ctr_vec = self.get_model_stat1(speakerID) \
                         - numpy.mean(self.get_model_stat1(speakerID), axis=0)
             W += numpy.dot(spk_ctr_vec.transpose(), spk_ctr_vec)
@@ -1505,7 +1506,7 @@ class StatServer:
 
             if save_partial:
                 sidekit.sidekit_io.write_fa_hdf5((mean, V, None, None, sigma),
-                                                 save_partial + "_{}_between_class.h5".format(it))
+                                                  "Partial_plda_{}_between_class.h5".format(it))
 
         return V, sigma
 
